package Task::MapMetro::Dev;

our $VERSION = '0.1100'; # VERSION

1;

# ABSTRACT: Everything useful when developing Map::Metro maps

__END__

=pod

=encoding utf-8

=head1 NAME

Task::MapMetro::Dev - Everything useful when developing Map::Metro maps

=head1 VERSION

version 0.1100

=head1 SYNOPSIS

    # install graphviz.
    # eg:
    $ sudo apt-get install graphviz

    # and then
    $ cpanm Task::MapMetro::Dev

=head1 TASK CONTENTS

=head2

=head3 L<GraphViz2> 2.20

=head3 L<Dist::Zilla> 5.000

=head3 L<Map::Metro> 0.2203

=head3 L<Dist::Zilla::MintingProfile::MapMetro::Map> 0.1401

=head3 L<Dist::Zilla::Plugin::MapMetro::MakeGraphViz> 0.1100

=head3 L<Dist::Zilla::Plugin::MapMetro::MakeLinePod> 0.1200

=head1 SEE ALSO

L<Map::Metro>

L<Task::MapMetro::Maps>

=head1 AUTHOR

Erik Carlsson <info@code301.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by Erik Carlsson.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
